from pathlib import Path

base_directory = Path(__file__).resolve().parent
CORTEX_ROOT = base_directory / "ext/cortex"
MINIMAP2 = base_directory / "ext/minimap2"
VCFTOOLS_DIRECTORY = base_directory / "ext/vcftools"
